@@ -907,6 +907,15 @@ def nonCollinear5PointsStylusFun(P, args, verbose=True):
         P3 = Pf[nameP3]
         P4 = Pf[nameP4]
         P5 = Pf[nameP5]
+        
+    Nf = P1.shape[0]
+    
+    # Find off-plane versor
+    v = np.zeros((Nf,3))
+    for i in range(Nf):
+        cplane = getNormalToLSPlane(np.array((P1[i,:], P2[i,:], P3[i,:], P4[i,:], P5[i,:])))
+        _v = np.dot(np.cross(P3[i,:] - P2[i,:], P5[i,:] - P2[i,:]), cplane)
+        v[i,:] = np.sign(_v) * args['offPlaneDist'] * cplane
 
     if args['algoTrilat'] == 0:
 
@@ -924,10 +933,8 @@ def nonCollinear5PointsStylusFun(P, args, verbose=True):
         # Perform trilaterations
         if (verbose):
             print('Performing trilaterations ...')
-        Nf = P1.shape[0]
         u1 = np.zeros((Nf,3))
         u2 = np.zeros((Nf,3))
-        v = np.zeros((Nf,3))
         for i in range(Nf):
 
             # Perform trilateration with markers P1-P3-P5
@@ -940,11 +947,6 @@ def nonCollinear5PointsStylusFun(P, args, verbose=True):
             #print np.linalg.norm(_v2)
             u2[i,:] = _u2
 
-            # Find off-plane versor
-            cplane = getNormalToLSPlane(np.array((P1[i,:], P2[i,:], P3[i,:], P4[i,:], P5[i,:])))
-            _v = np.dot(np.cross(P3[i,:] - P2[i,:], P5[i,:] - P2[i,:]), cplane)
-            v[i,:] = np.sign(_v) * args['offPlaneDist'] * cplane
-
         # Find the 2 tips
         if (verbose):
             print('Reconstructing 2 tips ...')
@@ -957,6 +959,30 @@ def nonCollinear5PointsStylusFun(P, args, verbose=True):
         if (verbose):
             print('Averaging 2 tips ...')
         tip = .5 * (tip1 + tip2)
+        
+    # Collect all global marker positions
+    mkrsAll = {}
+    mkrsAll[nameP1] = P1
+    mkrsAll[nameP2] = P2
+    mkrsAll[nameP3] = P3
+    mkrsAll[nameP4] = P4
+    mkrsAll[nameP5] = P5
+    mkrsAll['Tip'] = tip
+        
+    # Get wand direction
+    mkrDirectionTo = mkrsAll[args['direction']['to']]
+    mkrDirectionFrom = mkrsAll[args['direction']['from']] + v
+    direction = mkrDirectionTo - mkrDirectionFrom
+    direction /= np.linalg.norm(direction, axis=1)
+    directionMarkers = args['directionMarkers']
+    pathDirection = [None] * 2
+    pathDirection[0] = mkrsAll[directionMarkers[0]]
+    if (type(directionMarkers[1]) is dict):
+        pathDirection[1] = pathDirection[0] + directionMarkers[1]['aheadOf'] * direction
+    else:
+        pathDirection[1] = mkrsAll[directionMarkers[1]]
+    
+    infoFitting['pathDirection'] = pathDirection
 
     print('Tip calculated')
     return tip, infoFitting
