@@ -13,6 +13,12 @@ from itertools import groupby
 
 import os
 from mpl_toolkits.mplot3d import Axes3D
+import matplotlib
+from .pyver import __pyver
+if __pyver == 3:
+    matplotlib.use('Qt5Agg')
+else:
+    matplotlib.use('Qt4Agg')
 import matplotlib.pyplot as plt
 
 
